<?php

namespace Drupal\media_folders\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure settings for the media folder file.
 */
class MediaFolderFileConfigForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'media_folders_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'media_folders.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('media_folders.settings');

    $form['config'] = [
      '#type' => 'details',
      '#title' => $this->t('Configuration'),
      '#open' => TRUE,
    ];

    $form['config']['default_view'] = [
      '#type' => 'select',
      '#options' => [
        'thumbs' => $this->t('Folder view'),
        'list' => $this->t('List view'),
      ],
      '#required' => TRUE,
      '#title' => $this->t('Default View Mode'),
      '#default_value' => $config->get('default_view'),
    ];

    $form['config']['default_order'] = [
      '#type' => 'select',
      '#options' => [
        'az' => $this->t('Alphabetic ascending'),
        'za' => $this->t('Alphabetic descending'),
        'date-asc' => $this->t('Date ascending'),
        'date-desc' => $this->t('Date descending'),
      ],
      '#required' => TRUE,
      '#title' => $this->t('Default Order'),
      '#default_value' => $config->get('default_order'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('media_folders.settings')
      ->set('default_view', $form_state->getValue('default_view'))
      ->set('default_order', $form_state->getValue('default_order'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
